@@ -1,5 +1,8 @@
 #!/bin/bash
 
+# No module environment on the Mac
+[[ $(uname) == "Darwin" ]] && return
+
 # Initialise module environment if it is not
 if [[ ! $(command -v module > /dev/null 2>&1) ]]; then
   . /usr/local/apps/module/init/bash
