@@ -4,6 +4,10 @@
 if [[ ! $(command -v module > /dev/null 2>&1) ]]; then
   . /usr/local/apps/module/init/bash
 fi
-# grib_api module conflicts with intel module
+
+# Unload modules not available for Intel
 module unload grib_api
+module unload emos
+module unload fftw
+module unload libemos
 module switch gnu intel/15.0.2
