@@ -1,11 +1,11 @@
 /**
 * Copyright 1981-2012 ECMWF.
 *
-* This software is licensed under the terms of the Apache Licence 
+* This software is licensed under the terms of the Apache Licence
 * Version 2.0 which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
 *
-* In applying this licence, ECMWF does not waive the privileges and immunities 
-* granted to it by virtue of its status as an intergovernmental organisation 
+* In applying this licence, ECMWF does not waive the privileges and immunities
+* granted to it by virtue of its status as an intergovernmental organisation
 * nor does it submit to any jurisdiction.
 */
 
@@ -138,9 +138,9 @@ unsigned char * q = buffer;
     section4Offset = (fortint) (q - buffer);
     section4Length = THREEBYTEINT(q); q+= 3;
     if( large ){
-          total = total + section4Length;
-	  section4Length = total - section4Offset;  
-	  }
+      total = total + section4Length;
+      section4Length = total - section4Offset;
+    }
 /*
 //  Advance to end of section 4
 */
@@ -310,11 +310,12 @@ fortint status;
 
   status = prepareGrib( grib, buffer);
 
-  if( DEBUG1 )
+  if( DEBUG1 ) {
     if( status )
       printf("GDECODE: prepareGrib failed.\n");
     else
       printf("GDECODE: prepareGrib ran OK\n");
+  }
 
   return status;
 }
@@ -341,7 +342,7 @@ gribProduct * g = *grib;
 fortint IGTIME(gribProduct ** grib) {
 fortint time;
 gribProduct * g = *grib;
-  
+
   if( (g1_hour(g) == 255) || (g1_minute(g) == 255) ) return (fortint) -1;
 
   time = g1_hour(g)*100 +
@@ -353,7 +354,7 @@ gribProduct * g = *grib;
 fortint IGSTEP(gribProduct ** grib) {
 fortint timeunit, timerange, step;
 gribProduct * g = *grib;
-  
+
   switch( (int) g1_timeunit(g) ) {
 
     case 2:
@@ -1043,10 +1044,11 @@ int flag = g4_flag(grib);
      floatingPoint(grib) &&
      noAdditionalFlags(grib)) return 12;
 
-  if((!gridPoint(grib)))
+  if((!gridPoint(grib))) {
     if(simplePacking(grib)) return 12;
   else
     return 19;
+  }
 
   return 12;
 }
@@ -1238,7 +1240,7 @@ fortint primaryBitmapped = primaryBitmapPresent(g);
       if( primaryBitmapped ) primaryBitmap = (unsigned char*)(g->g3) + 6;
 
       if( secondaryBitmapPresent(g) ) {
-        if( differentWidths(g) ) 
+        if( differentWidths(g) )
           secondaryBitmap = (unsigned char *) listOfWidths + g4_p1(g);
         else
           secondaryBitmap = (unsigned char *) listOfWidths + 1;
@@ -1282,7 +1284,7 @@ fortint primaryBitmapped = primaryBitmapPresent(g);
 
           *(arr+loop) = minimum +
             ((fortdouble)(firstOrderValue+secondOrderValue))*scale;
-          numberNotMissing++; 
+          numberNotMissing++;
         }
         else
           *(arr+loop) = missingValue;
@@ -1416,7 +1418,7 @@ fortdouble latitudeStep, longitudeStep, north;
       GVALUES(grib,g->expandedValues,&numberOfValues,&notMissing,missingValue);
     if( status != numberOfValues ) return (fortint) -6;
   }
- 
+
   return (fortint) (g->currentPointIndex = 1);
 }
 
@@ -1500,13 +1502,13 @@ void * memoryPointer = (void *) malloc(size);
     exit(1);
   }
   if( DEBUG2 )
-    printf("allocateMemory: allocated memory pointer = %0x\n", memoryPointer);
+    printf("allocateMemory: allocated memory pointer = %p\n", memoryPointer);
   return memoryPointer;
 }
 
 void freeMemory(void * memoryPointer) {
   if( DEBUG2 )
-    printf("freeMemory: freeing memory pointer = %0x\n", memoryPointer);
+    printf("freeMemory: freeing memory pointer = %p\n", memoryPointer);
   if( memoryPointer != NULL ) free(memoryPointer);
   return;
 }
