@@ -1,11 +1,11 @@
 /**
 * Copyright 1981-2012 ECMWF.
 *
-* This software is licensed under the terms of the Apache Licence 
+* This software is licensed under the terms of the Apache Licence
 * Version 2.0 which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
 *
-* In applying this licence, ECMWF does not waive the privileges and immunities 
-* granted to it by virtue of its status as an intergovernmental organisation 
+* In applying this licence, ECMWF does not waive the privileges and immunities
+* granted to it by virtue of its status as an intergovernmental organisation
 * nor does it submit to any jurisdiction.
 */
 
@@ -45,6 +45,11 @@ char * name;
     }
 
     name = (char*) malloc(l1+1);
+    if( name == NULL ) {
+      perror("JCHMOD: malloc error (name)");
+      exit(1);
+    }
+
     for( i = 0; i < l1; i++)
       name[i] = filename[i];
     name[l1] = '\0';
@@ -63,3 +68,4 @@ char * name;
 fortint jchmod(char * filename, char * char_mode, long l1, long l2) {
   return jchmod_(filename,char_mode,l1,l2);
 }
+
