@@ -12,10 +12,11 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <fcntl.h>
-#include <sys/types.h>
 #include <unistd.h>
-#include <sys/mman.h>
 #include <string.h>
+#include <sys/types.h>
+#include <sys/mman.h>
+#include <sys/stat.h>
 #include "common/fortint.h"
 #include "common/fortreal.h"
 #include "common/JPointer.h"
@@ -34,7 +35,7 @@
 #define PBCLOSE pbclose_
 #endif
 
-#ifdef linux
+#if defined(linux) && !defined(darwin)
 # if !defined __off64_t_defined
 typedef __off64_t off64_t;
 #define __off64_t_defined
@@ -51,9 +52,17 @@ extern OFF_T ftello64(FILE *);
 #define OFF_T off_t
 #endif
 
+#if defined(CRAY)
+typedef void* _fcd;
+#else
+#define _fcd char *
+#endif
 
-
+void PBOPEN(fortint* unit, _fcd name, _fcd mode, fortint* iret, fortint l1, fortint l2);
+void PBCLOSE(fortint* unit, fortint* iret);
 void INTLOGT(char * message, long length);
+void JMAKGG(fortint* kunit, fortint* ktrunc, fortint* krow, fortfloat* plat, fortfloat* pleg, fortint* kret);
+
 FILE * pbfp(long);
 
 void JOPNGGSM(
@@ -131,8 +140,8 @@ C
 C     The filename for the legendre polynomials has the form:
 C         cf_xxxx_nnnn   Truncation xxxx, Gaussian number nnnn
 C     For example,
-C         cf_0213_0160          T213    N160
-C         cf_0106_0080          T106    N80
+C         cf_0213_0160   T213             N160
+C         cf_0106_0080   T106             N80
 C
 C     On the C90, the file of polynomials may be cached in /work/marsint
 C
@@ -191,15 +200,26 @@ char message[] = "JOPNGGSM: creating coefficients file";
 int status;
 pid_t process_id;
 int ktrunc = (int) (*iktrunc);
+char *dbg;
 
 /*
 //  Setup the file name
 */
   len_pleg =          sizeof(fortfloat) * (ktrunc+1) * (ktrunc+4) /2;
   len      =  *knum * sizeof(fortfloat) * (ktrunc+1) * (ktrunc+4) /2;
-  sprintf( ypfn+3, "%04d", ktrunc);
+
+  sprintf( ypfn+3,  "%04d", ktrunc);
   sprintf( ypfn+7, "_%04d", *knum);
 
+  dbg = getenv("JDCNDBG");
+  if (dbg==0 || (strncmp(dbg,"1",1) && strncmp(dbg,"2",1) && strncmp(dbg,"3",1))) {
+    dbg = 0;
+  }
+  if (dbg) {
+    fprintf(stdout,"INTLOG DEBUG: JOPNGGSM: Coefficients file to open is:\n",ypfn);
+    fprintf(stdout,"INTLOG DEBUG: %s\n",ypfn);
+  }
+
 /*
 //  If file already open, return the existing unit number
 */
@@ -342,7 +362,7 @@ int ktrunc = (int) (*iktrunc);
     }
 
 /*
-//  Close it, rename it, and open it again with read access
+//  Close it and rename it
 */
     free(pleg);
     PBCLOSE(&fpindex,kret);
@@ -352,43 +372,37 @@ int ktrunc = (int) (*iktrunc);
       *kret = (fortint) 995;
       return;
     }
-
-    l1 = strlen(filename);
-    l2 = 1;
-    PBOPEN(&fpindex,filename,"r",kret,l1,l2);
-    if( *kret ) {
-      perror("JOPNGGSM: PBOPEN error");
-      *kret = (fortint) 994;
-      return;
-    }
-    fp = pbfp((long)fpindex);
-    if( fp == NULL ) {
-      perror("JOPNGGSM: file pointer after PBOPEN is NULL");
-      *kret = (fortint) 994;
-      return;
-    }
   }
 
 /*
-//  Check the file size
+//  Check the file size and reopen it with read access
 */
-#ifdef FOPEN64
-  fseeko64(fp, 0, 2);
-  if( len != ftello64(fp) ) {
-#else
-  fseek(fp, 0, 2);
-  if( len != ftell(fp) ) {
-#endif
-    fprintf(stderr,"JOPNGGSM: coefficients file size should be %lld bytes\n", len)
-;
+  struct stat st;
+  if( -1==stat(filename,&st) ) {
+    perror(filename);
+    *kret = (fortint) 994;
+    return;
+  }
+  if( len != st.st_size ) {
+    fprintf(stderr,"JOPNGGSM: coefficients file size should be %lld bytes, but it is %lld bytes.\n", len, st.st_size);
     *kret = (fortint) 993;
     return;
   }
-#ifdef FOPEN64
-  fseeko64(fp, 0, 0);
-#else
-  fseek(fp, 0, 0);
-#endif
+
+  l1 = strlen(filename);
+  l2 = 1;
+  PBOPEN(&fpindex,filename,"r",kret,l1,l2);
+  if( *kret ) {
+    perror("JOPNGGSM: PBOPEN error");
+    *kret = (fortint) 992;
+    return;
+  }
+  fp = pbfp((long)fpindex);
+  if( fp == NULL ) {
+    perror("JOPNGGSM: file pointer after PBOPEN is NULL");
+    *kret = (fortint) 992;
+    return;
+  }
 
 /*
 //  Map the file
@@ -400,13 +414,11 @@ int ktrunc = (int) (*iktrunc);
 
 #ifdef FOPEN64
     result =  (void *) mmap64(addr,(size_t) len, (PROT_READ),
-                            MAP_SHARED,(int) nunit, (OFF_T)off);
+                            MAP_SHARED, (int) nunit, (OFF_T) off);
 #else
     result =  (void *) mmap(addr,(size_t) len, (PROT_READ),
-                            MAP_SHARED,(int) nunit,(OFF_T) off);
+                            MAP_SHARED, (int) nunit, (OFF_T) off);
 #endif
-    /* result =  (void *) mmap(addr,(size_t) len, (PROT_READ), */
-                            /* MAP_SHARED,(int) nunit,(off_t) off); */
 
     if( (caddr_t) result == (caddr_t) -1 ) {
       perror("JOPNGGSM: mmap error");
@@ -426,3 +438,4 @@ int ktrunc = (int) (*iktrunc);
 
   return;
 }
+
