@@ -9,26 +9,19 @@
 * nor does it submit to any jurisdiction.
 */
 
-#ifdef linux
-#ifndef __USE_LARGEFILE64
-#define __USE_LARGEFILE64
-#endif
-#include <sys/stat.h>
-#endif
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <fcntl.h>
-#include <sys/types.h>
 #include <unistd.h>
-#include <sys/mman.h>
 #include <string.h>
+#include <time.h>
+#include <sys/types.h>
+#include <sys/mman.h>
+#include <sys/stat.h>
 #include "common/fortint.h"
 #include "common/fortreal.h"
 #include "common/JPointer.h"
 
-
-
 #ifdef FORTRAN_NO_UNDERSCORE
 #define JOPNLLSM jopnllsm
 #define JMAKLL jmakll
@@ -43,7 +36,7 @@
 #define PBCLOSE pbclose_
 #endif
 
-#ifdef linux
+#if defined(linux) && !defined(darwin)
 # if !defined __off64_t_defined
 typedef __off64_t off64_t;
 #define __off64_t_defined
@@ -70,6 +63,15 @@ int iitimer(int *seconds)
     return (int)(timval1 - (time_t)*seconds);
 }
 
+#if defined(CRAY)
+typedef void* _fcd;
+#else
+#define _fcd char *
+#endif
+
+void PBOPEN(fortint* unit, _fcd name, _fcd mode, fortint* iret, fortint l1, fortint l2);
+void PBCLOSE(fortint* unit, fortint* iret);
+void JMAKLL(fortint* kunit, fortint* ktrunc, fortfloat* pintvl, fortfloat* plat, fortfloat* pleg, fortint* kret);
 void INTLOGT(char * message, long length);
 FILE * pbfp(long);
 
@@ -94,7 +96,7 @@ C
 C     Interface
 C     _________
 C
-C     CALL JOPNLLSM( IPDUM, PLATINC, KTRUNC, KUNIT, ZBUILD, KRET)
+C     CALL JOPNLLSM(IPDUM,PLATINC,KTRUNC,KUNIT,ZBUILD,KRET)
 C
 C     Input parameters
 C     ________________
@@ -147,12 +149,12 @@ C     Comments
 C     ________
 C
 C     The filename for the legendre polynomials has the form:
-C         cf_txxxx_raabbbb       Txxxx   aa.bbbb degrees
+C         cf_txxxx_raabbbb    Truncation xxxx, aa.bbbb degrees
 C     For example,
-C         cf_t0213_r0050000      T213    0.5 degrees
-C         cf_t0106_r0250000      T106    2.5 degrees
+C         cf_t0213_r0050000   T213             0.5 degrees
+C         cf_t0106_r0250000   T106             2.5 degrees
 C
-C     On the C90, the file of polynomials may be cached in /owrk/marsint
+C     On the C90, the file of polynomials may be cached in /work/marsint
 C
 C     Otherwise the file is located in (or will be created in) the first
 C     directory given by one of the following (in the order listed, if
@@ -194,9 +196,8 @@ static char yarray[12][21];
 static int ncnt = 0;
 static int nunit = -1;
 int i;
-OFF_T len, len_pleg, knum;
+OFF_T len, len_pleg;
 static OFF_T oldlen;
-int kbuild ;
 char * fn;
 static fortint fpindex;
 static FILE * fp;
@@ -206,38 +207,41 @@ static void * oldresult = 0;
 static void * resultarray[12];
 static int unitarray[12];
 fortfloat plat = 0.0;
+int kbuild ;
+OFF_T knum;
 fortfloat * pleg;
 int exist = 0;
 char message[] = "JOPNLLSM: creating coefficients file";
 int status;
 pid_t process_id;
 int ktrunc = (int) (*iktrunc);
+char *dbg;
 
 /*
 //  Setup the file name
 */
-  len_pleg =  sizeof(fortfloat) * (ktrunc+1) * (ktrunc+4) /2;
-
+  len_pleg =          sizeof(fortfloat) * (ktrunc+1) * (ktrunc+4) /2;
   *zbuild = *platinc;
-
-  knum = (OFF_T) ((90.0/(*zbuild)) + 0.5) + 1;
-  len  = (OFF_T) (knum * sizeof(fortfloat) * (ktrunc+1) * (ktrunc+4)/2);
-
-/*
-printf("################# len: %lld, knum: %lld, sizeof(double): %d, ktrunc+1: %d, ktrunc+4: %d\n",len,knum,sizeof(double),(ktrunc+1),(ktrunc+4));
-*/
-
-/*
-//  Setup the file name
-*/
-  sprintf( ypfn+4, "%04d", ktrunc);
   kbuild = (int) (((*zbuild)*100000.0) + 0.5);
+  knum = (OFF_T) ((90.0/(*zbuild)) + 0.5) + 1;
+  len  = (OFF_T) (knum * sizeof(fortfloat) * (ktrunc+1) * (ktrunc+4) /2);
+
+  sprintf( ypfn+4, "%04d", ktrunc);
 #ifdef REAL_8
   sprintf( ypfn+8, "_R%07d", kbuild);
 #else
   sprintf( ypfn+8, "_r%07d", kbuild);
 #endif
 
+  dbg = getenv("JDCNDBG");
+  if (dbg==0 || (strncmp(dbg,"1",1) && strncmp(dbg,"2",1) && strncmp(dbg,"3",1))) {
+    dbg = 0;
+  }
+  if (dbg) {
+    fprintf(stdout,"INTLOG DEBUG: JOPNLLSM: Coefficients file to open is:\n",ypfn);
+    fprintf(stdout,"INTLOG DEBUG: %s\n",ypfn);
+  }
+
 /*
 //  If file already open, return the existing unit number
 */
@@ -268,14 +272,13 @@ printf("################# len: %lld, knum: %lld, sizeof(double): %d, ktrunc+1: %
       *kret = (fortint) 999;
       return;
     }
-
   }
 */
 
 /*
   If more than 12 files are memory mapped , error
 */
-  if(ncnt==13) {
+  if(ncnt>=12) {
     fprintf(stderr,"JOPNLLSM: attempt to memory map more than 12 files\n");
     *kret = (fortint) 999;
     return;
@@ -374,7 +377,6 @@ printf("################# len: %lld, knum: %lld, sizeof(double): %d, ktrunc+1: %
       *kret = (fortint) 996;
       return;
     }
-
     JMAKLL( &fpindex, iktrunc, zbuild, &plat, pleg, kret);
     if( *kret != 0 ) {
       free(pleg);
@@ -382,7 +384,7 @@ printf("################# len: %lld, knum: %lld, sizeof(double): %d, ktrunc+1: %
     }
 
 /*
-//  Close it, rename it, and open it again with read access
+//  Close it and rename it
 */
     free(pleg);
     PBCLOSE(&fpindex,kret);
@@ -392,76 +394,37 @@ printf("################# len: %lld, knum: %lld, sizeof(double): %d, ktrunc+1: %
       *kret = (fortint) 995;
       return;
     }
-
-    l1 = strlen(filename);
-    l2 = 1;
-    PBOPEN(&fpindex,filename,"r",kret,l1,l2);
-    if( *kret ) {
-      perror("JOPNLLSM: PBOPEN error");
-      return;
-    }
-    fp = pbfp((long)fpindex);
-    if( fp == NULL ) {
-      perror("JOPNLLSM: file pointer after PBOPEN is NULL");
-      *kret = (fortint) 994;
-      return;
-    }
   }
 
 /*
-//  Check the file size
+//  Check the file size and reopen it with read access
 */
-#ifdef FOPEN64
-
-#ifdef linux
-/* On Linux -m32, lseek64 doesn't work. Use fstat64 instead */
-
-{
-
-    struct stat64 st;
-
-    if(fstat64(fileno(fp),&st) == -1)
-    {
-        fprintf(stderr,"JOPNLLSM: coefficients file fstat failed\n");
-        *kret = (fortint) 993;
-        return;
-    }
-    else
-    {
-        if(len != st.st_size)
-        {
-            fprintf(stderr,"JOPNLLSM: coefficients file size should be %lld bytes, it is %lld\n", len,st.st_size);
-            *kret = (fortint) 993;
-            return;
-        }
-    }
-}
-#else
-  fseeko64(fp, 0, 2);
-  if( len != ftello64(fp) ) {
-    long long ftello = ftello64(fp);
-    fprintf(stderr,"JOPNLLSM: coefficients file size should be %lld bytes, it is %lld\n", len,ftello);
+  struct stat st;
+  if( -1==stat(filename,&st) ) {
+    perror(filename);
+    *kret = (fortint) 994;
+    return;
+  }
+  if( len != st.st_size ) {
+    fprintf(stderr,"JOPNLLSM: coefficients file size should be %lld bytes, but it is %lld bytes.\n", len, st.st_size);
     *kret = (fortint) 993;
     return;
   }
-#endif
 
-#else
-  fseek(fp, 0, 2);
-  if( len != ftell(fp) ) {
-    long ftello = ftell(fp);
-
-    fprintf(stderr,"JOPNLLSM: coefficients file size should be %ld bytes, it is %ld\n", len,ftello);
-    *kret = (fortint) 993;
+  l1 = strlen(filename);
+  l2 = 1;
+  PBOPEN(&fpindex,filename,"r",kret,l1,l2);
+  if( *kret ) {
+    perror("JOPNLLSM: PBOPEN error");
+    *kret = (fortint) 992;
+    return;
+  }
+  fp = pbfp((long)fpindex);
+  if( fp == NULL ) {
+    perror("JOPNLLSM: file pointer after PBOPEN is NULL");
+    *kret = (fortint) 992;
     return;
   }
-#endif
-
-#ifdef FOPEN64
-  fseeko64(fp, 0, 0);
-#else
-  fseek(fp, 0, 0);
-#endif
 
 /*
 //  Map the file
@@ -476,14 +439,14 @@ printf("################# len: %lld, knum: %lld, sizeof(double): %d, ktrunc+1: %
 
 #ifdef FOPEN64
     result =  (void *) mmap64(addr,(size_t) len, (PROT_READ),
-                            MAP_SHARED,(int) nunit, (OFF_T)off);
+                            MAP_SHARED, (int) nunit, (OFF_T) off);
 #else
     result =  (void *) mmap(addr,(size_t) len, (PROT_READ),
-                            MAP_SHARED,(int) nunit,(OFF_T) off);
+                            MAP_SHARED, (int) nunit, (OFF_T) off);
 #endif
 
     if( (caddr_t) result == (caddr_t) -1 ) {
-      perror("JOPNLLSM: mmap64 error");
+      perror("JOPNLLSM: mmap error");
       *kret = (fortint) 992;
       return;
     }
@@ -503,3 +466,4 @@ printf("################# len: %lld, knum: %lld, sizeof(double): %d, ktrunc+1: %
 
   return;
 }
+
