@@ -7,7 +7,7 @@ C In applying this licence, ECMWF does not waive the privileges and immunities
 C granted to it by virtue of its status as an intergovernmental organisation 
 C nor does it submit to any jurisdiction.
 C
-      REAL QG08018(80)
+      INTEGER QG08018(80)
       DATA QG08018/
      X  18 ,  25 ,  36 ,  40,
      X  45 ,  54 ,  60 ,  64,
