@@ -7,7 +7,7 @@ C In applying this licence, ECMWF does not waive the privileges and immunities
 C granted to it by virtue of its status as an intergovernmental organisation 
 C nor does it submit to any jurisdiction.
 C
-      REAL QG096(96)
+      INTEGER QG096(96)
       DATA QG096/
      X 18 , 25 , 36 , 40,
      X 45 , 50 , 60 , 64,
@@ -32,4 +32,4 @@ C
      X 384 , 384 , 384 , 384,
      X 384 , 384 , 384 , 384,
      X 384 , 384 , 384 , 384,
-     X 384 , 384 , 384 , 384 / 
\ No newline at end of file
+     X 384 , 384 , 384 , 384 / 
