@@ -925,12 +925,12 @@ void pbread5_(fortint* unit,char* buffer,size_t* nbytes,size_t* iret) {
 //               otherwise, = number of bytes read.
 */
     if( DEBUG )
-      printf("PBIO_READ5: number of bytes to read = %d\n", *nbytes);
+      printf("PBIO_READ5: number of bytes to read = %lu\n", *nbytes);
 
     *iret = read(*unit, buffer, *nbytes);
 
     if( DEBUG )
-      printf("PBIO_READ5: number of bytes read = %d\n", *iret);
+      printf("PBIO_READ5: number of bytes read = %lun", *iret);
 /*
 // Error in file-handling
 */
@@ -943,7 +943,7 @@ void pbread5_(fortint* unit,char* buffer,size_t* nbytes,size_t* iret) {
 // Read problem
 */
     else if(*iret != *nbytes) {
-      printf("EOF; pbread5; bytes requested %d; read in: %d\n",
+      printf("EOF; pbread5; bytes requested %lu; read in: %lu\n",
              *nbytes,*iret);
       *iret = -1;
       return;
@@ -1383,7 +1383,7 @@ long offset, loop = 1;
     offset = (fortint) fileTell( CURRENT_FILE);
     if( DEBUG ) {
       printf("PBIO_SIZE: fptable slot = %d. ", *unit);
-      printf("Current file position = %d\n", offset);
+      printf("Current file position = %lu\n", offset);
     }
 
     *plen = BUFFLEN;
@@ -1426,7 +1426,7 @@ long offset, loop = 1;
 //  Put the file pointer back where it started
 */
     if( DEBUG ) {
-      printf("PBIO_SIZE: file pointer set back to: %d\n", offset);
+      printf("PBIO_SIZE: file pointer set back to: %lu\n", offset);
       printf("PBIO_SIZE: Product size = %d\n", *plen);
     }
     offset = (fortint) fileSeek( CURRENT_FILE, offset, SEEK_SET);
